package de.informatics4kids.hopfield;

import java.util.Arrays;

public class MathVector {

	/**
	 * Tupel des Vektors.
	 */
	public int[] tuple;

	/**
	 * Dieser sog. Kontruktor wird bei der Erstellung des Vektors einmal
	 * automatisch aufgerufen, um den Vektor zu konstruieren.
	 */
	public MathVector(int dimension) {
		tuple = new int[dimension];
	}

	/**
	 * Errechnet die Dimension des Vektors, also die Anzahl der Elemente im
	 * Tupel.
	 *
	 * @return Die Dimension
	 */
	public int dimension() {
		return tuple.length;
	}

	/**
	 * Errechnet das Skalarprodukt aus diesem Vektor und dem gegebenen anderen.
	 *
	 * @param other
	 *            - Der andere Faktor im Skalarprodukt
	 * @return Das Skalarprodukt
	 */
	public int scalarProduct(MathVector other) {
		int sum = 0;
		for (int i = 0; i < tuple.length; i++) {
			int product = tuple[i] * other.tuple[i];
			sum += product;
		}
		return sum;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		MathVector other = (MathVector) obj;
		if (!Arrays.equals(tuple, other.tuple))
			return false;
		return true;
	}
}